@@ -1323,6 +1323,7 @@ gog_renderer_get_pixbuf (GogRenderer *rend)
 	if (rend->cairo_surface == NULL)
 		return NULL;
 
+#ifdef GOFFICE_WITH_GTK
 	if (rend->pixbuf == NULL) {
 		int width = cairo_image_surface_get_width (rend->cairo_surface);
 		int height = cairo_image_surface_get_height (rend->cairo_surface);
@@ -1333,6 +1334,7 @@ gog_renderer_get_pixbuf (GogRenderer *rend)
 							 width, height, rowstride, NULL, NULL);
 		go_cairo_convert_data_to_pixbuf (data, NULL, width, height, rowstride);
 	}
+#endif
 
 	return rend->pixbuf;
 }
@@ -1345,6 +1347,7 @@ gog_renderer_get_cairo_surface (GogRenderer *rend)
 	return rend->cairo_surface;
 }
 
+#ifdef GOFFICE_WITH_GTK
 static gboolean
 _gsf_gdk_pixbuf_save (const gchar *buf,
 		      gsize count,
@@ -1359,6 +1362,7 @@ _gsf_gdk_pixbuf_save (const gchar *buf,
 
 	return ok;
 }
+#endif
 
 static cairo_status_t
 _cairo_write_func (void *closure,
@@ -1450,6 +1454,7 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 	gog_graph_get_size (rend->model, &width_in_pts, &height_in_pts);
 
 	switch (format) {
+		case GO_IMAGE_FORMAT_EPS:
 		case GO_IMAGE_FORMAT_PDF:
 		case GO_IMAGE_FORMAT_PS:
 		case GO_IMAGE_FORMAT_SVG:
@@ -1496,6 +1501,21 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 #else
 					g_warning ("[GogRendererCairo::export_image] cairo SVG backend missing");
 					return FALSE;
+#endif
+				case GO_IMAGE_FORMAT_EPS:
+					rend->marker_as_surface = FALSE;
+#ifdef HAVE_CAIRO_PS_SURFACE_SET_EPS
+					surface = cairo_ps_surface_create_for_stream
+						(_cairo_write_func,
+						 output, width_in_pts, height_in_pts);
+					cairo_ps_surface_set_eps (surface, TRUE);
+#ifdef HAVE_CAIRO_SURFACE_SET_FALLBACK_RESOLUTION
+					cairo_surface_set_fallback_resolution (surface, x_dpi, y_dpi);
+#endif
+					break;
+#else
+					g_warning ("[GogRendererCairo::export_image] cairo EPS backend missing");
+					return FALSE;
 #endif
 				default:
 					break;
@@ -1524,13 +1544,15 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 			if (pixbuf == NULL)
 				return FALSE;
 			format_info = go_image_get_format_info (format);
+#ifdef GOFFICE_WITH_GTK
 			if (!format_info->alpha_support)
-				output_pixbuf = gdk_pixbuf_composite_color_simple (pixbuf,
-										   gdk_pixbuf_get_width (pixbuf),
-										   gdk_pixbuf_get_height (pixbuf),
-										   GDK_INTERP_NEAREST,
-										   255, 256, 0xffffffff,
-										   0xffffffff);
+				output_pixbuf = gdk_pixbuf_composite_color_simple
+					(pixbuf,
+					 gdk_pixbuf_get_width (pixbuf),
+					 gdk_pixbuf_get_height (pixbuf),
+					 GDK_INTERP_NEAREST,
+					 255, 256, 0xffffffff,
+					 0xffffffff);
 			else
 				output_pixbuf = pixbuf;
 			result = gdk_pixbuf_save_to_callback (output_pixbuf,
@@ -1540,7 +1562,7 @@ gog_renderer_export_image (GogRenderer *rend, GOImageFormat format,
 			if (!format_info->alpha_support)
 				g_object_unref (output_pixbuf);
 			return result;
-			break;
+#endif
 	}
 
 	return FALSE;
